# Generated by Django 5.2.8 on 2025-12-16 10:56

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_ip_access', '0001_initial'),
    ]

    operations = [
        migrations.RenameIndex(
            model_name='grantedip',
            new_name='granted_ips_ip_addr_642e69_idx',
            old_name='django_ip_a_ip_add_123456_idx',
        ),
    ]
